@@ -1,8 +1,10 @@
 use Test;
 BEGIN { plan tests => 3 };
-use Text::DiffParagraph;
+use Text::ParagraphDiff;
 ok(1);
-my $newdiff = text_diff("t/old.txt","t/new.txt",{plain=>1});
+my $newdiff = text_diff("t/old.txt","t/new.txt"
+#,{plain=>1}
+);
 ok(1);
 
 open (OLD_DIFF,"t/diff.t") or die $!;
